@@ -247,8 +247,8 @@ class HdDB:
         """
         try:
 
-            end_row = params.get("end_row", 0)
-            start_row = params.get("start_row", 0)
+            end_row = params.end_row or 0
+            start_row = params.start_row or 0
             page_size = end_row - start_row
 
             select_sql = build_select_sql(params)
@@ -261,6 +261,7 @@ class HdDB:
             query = f"{select_sql} {from_sql} {where_sql} {group_sql} {order_sql} {limit_sql}"
 
             logger.info(f"Executing query: {query}")
+
             data = self.execute(query).fetchdf()
 
             count_query = f'SELECT COUNT(*) FROM "{org}__{db}"."{tbl}"'
